@@ -99,11 +99,13 @@ def main(argv=None):
 
     try:
         base_dir, prefix_dir = calculate_paths(config)
-        swift_store = SwiftStore(config['swift_key'], config['swift_tenant'], config['swift_url'], config['swift_user'], prefix_dir)
+        swift_store = SwiftStore(config['swift_key'], config['swift_region'], config['swift_tenant'],
+                                 config['swift_url'], config['swift_user'], prefix_dir)
         fs_store = FSStore(base_dir, prefix_dir)
         upload_time = datetime.today()
 
-        EpochFiles(os.path.join(base_dir, prefix_dir), config['snapshot_name'], upload_time).archive()
+        epoch_files = EpochFiles(os.path.join(base_dir, prefix_dir), config['snapshot_name'], upload_time)
+        epoch_files.archive()
 
         # Grab the local and swift metadata
         current_metadata = DirectoryMetadata(fs_store, upload_time)
@@ -135,6 +137,7 @@ def main(argv=None):
             # Do a diff with all that is in swift, anything in swift but not in the combined set can be deleted.
             should_be_empty, to_del = combined_metadata.diff(swift_metadata)
             if len(should_be_empty) != 0:
+                exit_status = 1
                 log.error(
                     "ERROR: Found files in the %d combined retained backups that were not in swift.\n%s"
                     % (config['retain'], should_be_empty)
@@ -153,6 +156,8 @@ def main(argv=None):
 
     except:
         log.exception('Unhandled Exception in Backup upload')
+        # Move the Epoch files back to their original names so a retry run does not encounter issues with them
+        epoch_files.restore()
         exit_status = 1
 
     # Status message and exit
